pub struct Interface {
pub capability_id: CapabilityId,
pub direction: InterfaceDirection,
pub codimension: usize,
}Expand description
A marked interface on a namespace: a capability with a direction.
In the operadic framework, output interfaces of one namespace can be glued to input interfaces of another.
Fields
capability_id: CapabilityIdWhich capability this interface is associated with
direction: InterfaceDirectionDirection of the interface
codimension: usizeCodimension of the underlying Schubert class
Implementations
Sourceimpl Interface
impl Interface
Sourcepub fn new(
capability_id: CapabilityId,
direction: InterfaceDirection,
codimension: usize,
) -> Self
pub fn new( capability_id: CapabilityId, direction: InterfaceDirection, codimension: usize, ) -> Self
Create a new interface.